package rrdService.service;
import rrdService.util.*;
import java.rmi.*;
import java.io.*;
import java.lang.*;
import java.awt.*;
/**	
* The interface RoundRobinDataBaseItf is the remote interface of RoundRobinDataBase
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="RoundRobinDataBaseItf.java">RoundRobinDataBaseItf</a>
* @see RoundRobinItf RoundRobin
*/
public interface RoundRobinDataBaseItf extends Remote, RoundRobinItf {
	/**
	* getSize return the size of RoundRobinDataBase
	* @return long
	*/
	public long getSize() throws RemoteException;
	/**
	* delete delete a rrd
	* @return int the number of rrd delete
	*/
	public int delete() throws RemoteException;
	/**
	* Update update a round robin database
	* @param template The template switch allows you to specify which data sources you are going to update and in which order. 
	* @param dataContainer The data used for updating the RRD was acquired at a certain time. 
	*/
	public void update(Template template, DataContainer dataContainer) throws RemoteException ;
	/**
	* Update update a round robin database
	* @param dataContainer The data used for updating the RRD was acquired at a certain time. 
	*/
	public void update(DataContainer dataContainer) throws RemoteException ;
	/**
	* Update update a round robin database
	* @param data The data used for updating the RRD was acquired at a certain time. 
	*/
	public void update(Data data) throws RemoteException ;
	/**
	* fetch fetch a round robin database
	* @param cf which consolidation function should have been applied to the data you want to fetch? (AVERAGE,MIN,MAX,LAST) 
	* @param resolution what interval should the values have (seconds per value). rrdfetch will try to match your request, but it will return data even if no absolute match is possible. 
	* @param startTime when should the data begin. A time in seconds since epoch (1970-01-01) is required. Negative numbers are relative to the current time. By default one day worth of data will be fetched. See also AT-STYLE TIME SPECIFICATION section for a detailed explanation on ways to specify start time. 
	* @param endTime when should the data end. Time in seconds since epoch. See also AT-STYLE TIME SPECIFICATION section for a detailed explanation of how to specify end time. 
	*/
	public String fetch(String cf, int resolution, Time startTime, Time endTime) throws RemoteException ;
	/**
	* fetch fetch a round robin database
	* @param cf which consolidation function should have been applied to the data you want to fetch? (AVERAGE,MIN,MAX,LAST) 
	* @param startTime when should the data begin. A time in seconds since epoch (1970-01-01) is required. Negative numbers are relative to the current time. By default one day worth of data will be fetched. See also AT-STYLE TIME SPECIFICATION section for a detailed explanation on ways to specify start time. 
	* @param endTime when should the data end. Time in seconds since epoch. See also AT-STYLE TIME SPECIFICATION section for a detailed explanation of how to specify end time. 
	*/
	public String fetch(String cf, Time startTime, Time endTime) throws RemoteException ;
	/**
	* fetch fetch a round robin database
	* @param cf which consolidation function should have been applied to the data you want to fetch? (AVERAGE,MIN,MAX,LAST) 
	* @param resolution what interval should the values have (seconds per value). rrdfetch will try to match your request, but it will return data even if no absolute match is possible. 
	* @param startTime when should the data begin. A time in seconds since epoch (1970-01-01) is required. Negative numbers are relative to the current time. By default one day worth of data will be fetched. See also AT-STYLE TIME SPECIFICATION section for a detailed explanation on ways to specify start time. 
	*/
	public String fetch(String cf, int resolution, Time startTime) throws RemoteException ;
	/**
	* fetch fetch a round robin database
	* @param cf which consolidation function should have been applied to the data you want to fetch? (AVERAGE,MIN,MAX,LAST) 
	* @param startTime when should the data begin. A time in seconds since epoch (1970-01-01) is required. Negative numbers are relative to the current time. By default one day worth of data will be fetched. See also AT-STYLE TIME SPECIFICATION section for a detailed explanation on ways to specify start time. 
	*/
	public String fetch(String cf, Time startTime) throws RemoteException ;
	/**
	* fetch fetch a round robin database
	* @param cf which consolidation function should have been applied to the data you want to fetch? (AVERAGE,MIN,MAX,LAST) 
	* @param resolution what interval should the values have (seconds per value). rrdfetch will try to match your request, but it will return data even if no absolute match is possible. 
	* @param startTime when should the data begin. A time in seconds since epoch (1970-01-01) is required. Negative numbers are relative to the current time. By default one day worth of data will be fetched. See also AT-STYLE TIME SPECIFICATION section for a detailed explanation on ways to specify start time. 
	*/
	public String fetch(String cf, int resolution) throws RemoteException ;
	/**
	* fetch fetch a round robin database
	* @param cf which consolidation function should have been applied to the data you want to fetch? (AVERAGE,MIN,MAX,LAST) 
	*/
	public String fetch(String cf) throws RemoteException ;
	/**
	* last return the date of the last data sample in an RRD
	*/
	public Time last() throws RemoteException ;
	/**
	* setHeartbeat modify the heartbeat of this RRD
	* @param dsName the ds-name of data source of this RRD to modify
	* @param heartbeat the new heartbeat of this RRD
	*/
	public void setHeartbeat(String dsName, int heartbeat) throws RemoteException ;
	/**
	* setMinimum modify the minimum of this RRD
	* @param dsName the ds-name of data source of this RRD to modify
	* @param minimum the new minimum of this RRD
	*/
	public void setMinimum(String dsName, int minimum) throws RemoteException ;
	/**
	* setMaximum modify the maximum of this RRD
	* @param dsName the ds-name of data source of this RRD to modify
	* @param maximum the new maximum of this RRD
	*/
	public void setMaximum(String dsName, int maximum) throws RemoteException ;
	/**
	* setDataSourceType modify the type of data source of this RRD
	* @param dsName the ds-name of data source of this RRD to modify
	* @param dataSourceType the new type of data source of this RRD
	*/
	public void setDataSourceType(String dsName, String dataSourceType) throws RemoteException ;
	/**
	* setDataSourceName modify the name of data source of this RRD
	* @param oldDsName the ds-name of data source of this RRD to modify
	* @param newDsName the new name of data source of this RRD
	*/
	public void setDataSourceName(String oldDsName, String newDsName) throws RemoteException ;
	/**
	* getInfo return info about a round robin database
	*/
	public String info() throws RemoteException ;
	/**
	* Returns the version of the round robin
	*/
	public String getRoundRobineVersion() throws RemoteException ;
	/**
	* Returns the step of the round robin
	*/
	public int getStep() throws RemoteException ;
	/**
	* Returns the data source container of the round robin
	*/
	public DataSourceContainer getDataSourceContainer() throws RemoteException ;
	/**
	* Returns the round robin archive container of the round robin
	*/
	public RoundRobinArchiveContainer getRoundRobinArchiveContainer() throws RemoteException ;
	/**
	* dump dump a round robin database
	* The dump function prints the contents of an RRD in human readable (?) XML format. This format can be read by rrdrestore. Together they allow you to transfer your files from one architecture to another as well as manipulating the contents of an RRD file in a somewhat more convenient manner.
	* @param xmlFilename the name of the output xlm file 
	*/
	public File dump(String xmlFilename) throws RemoteException ;
	/**
	* restore the contents of an RRD from its XML dump format
	* @param xmlFilename the name of the input xlm file 
	*/
	public RoundRobinDataBaseItf restore(String xmlFilename) throws RemoteException ;
	/**
	* grow used if you want to add extra rows to an RRA. The extra rows will be inserted as the rows that are oldest. 
	* @param rraNum the RRA you want to alter. You can find the number using rrdtool info.
	* @param rows the number of rows you want to add. 
	*/
	public void grow(int rraNum, int rows) throws RemoteException ;
	/**
	* shrink used if you want to remove rows from an RRA. The rows that will be removed are the oldest rows. 
	* @param rraNum the RRA you want to alter. You can find the number using rrdtool info.
	* @param rows the number of rows you want to remove. 
	*/
	public void shrink(int rraNum, int rows) throws RemoteException ;
	/**
	* graph Create a graph based on data from one or several RRD
	* @param roundRobinGraphic the roundRobinGraphic which represent the graph
	* @return Image the image built
	*/
	public RoundRobinImage graph(RoundRobinGraphic roundRobinGraphic) throws RemoteException ;
}