package rrdService.service;
import rrdService.util.*;
import java.rmi.*;
import java.rmi.server.UnicastRemoteObject;
import java.rmi.registry.*;
import java.net.*;
import java.io.*;
import java.lang.*;
import java.util.*;
/**	
* The class RoundRobinService is the implemtation of RoundRobinService
* @author Pellier Damien 
* @version	1.0
* date : 15/07/2001
* <dt><b>key-word</b><code>
* <dd>	RMI
* </code>
* @see <a href="RoundRobinService.java">RoundRobinService</a>
* @see RoundRobinServiceItf
*/
public class RoundRobinService extends UnicastRemoteObject implements RoundRobinServiceItf {
	/**
	* URL of RoundRobinService
	*/
	public static String serviceURL;
	/**
	* Port of RoundRobinService
	*/
	private static int servicePort;
	/**
	* Mount library of RoundRobinService
	*/
	private static String serviceMountLibrary;
	/**
	* time zone of reference  for rrdService
	*/
	public static TimeZone timeZone;
	/**
	* Time between two executions of th image grabage collector
	*/
	public static long imageGCClock = 300; // seconds
	/**
	* Ref on stub of homeRoundRobinLibrary
	*/
	private static RoundRobinLibraryItf homeRoundRobinLibrary ;
	/**
	* Table of lock on RoundRobin
	*/
	public static LockTable lockTable;
	/**
	* Constructor of class RoundRobinService
	*/
	public RoundRobinService() throws RemoteException {
		super();
	}
	public static String rmi;
	/**
	* InitRoundRobinService bind the RoundRobinService to the registry
	* @param file the file of config
	*/
	private static void initRoundRobinService(String file) throws Exception {
		// Cration du fichier de log
		new LogFile();
		// Lecture du fichier de configuration
		ConfigFile configFile = new ConfigFile(file);
		serviceURL = configFile.getServiceURL();
		// Traitement de l'url
		if (!serviceURL.substring(0, 2).equals("//")) 
			throw new Exception("Url format error");
		// Extraction des informations de url
		String serviceAddress;
		String path;
		if (serviceURL.substring(2, serviceURL.length()).indexOf("/") == -1) {
			serviceAddress = serviceURL;
			path = "";
		}
		else {
			serviceAddress = serviceURL.substring(0, serviceURL.substring(2, serviceURL.length()).indexOf("/")+2);
			path = serviceURL.substring(serviceURL.substring(2, serviceURL.length()).indexOf("/")+2, serviceURL.length());
		}
		servicePort = Integer.parseInt(configFile.getServicePort());
		serviceMountLibrary = configFile.getServiceMountLibrary();
		timeZone = configFile.getServiceTimeZone();
		// Enregistrement du service au registry	
		Registry registry = LocateRegistry.createRegistry(servicePort);
		rmi = serviceAddress+":"+servicePort+path;
		Naming.rebind(serviceAddress+":"+servicePort+path, ((RoundRobinServiceItf)new RoundRobinService()));
		// Crer la bibliothque racine
		homeRoundRobinLibrary = createHomeLibrary(serviceMountLibrary);
		// Dmarrage du garbage collector d'images
		ImageGarbageCollector imageGC = new ImageGarbageCollector(new File(serviceMountLibrary));
		Timer timer = new Timer(true);
		timer.scheduleAtFixedRate(imageGC, new Date(), imageGCClock*1000);
		// Affichage des paramtre slectionns
		LogFile.print("Server bound in registry: "+
			"URL="+serviceURL+
			" Port="+servicePort+
			" Mount Library="+serviceMountLibrary);
	}
	/**
	* createHomeLibrary create the directory of the home library
	* @param path the path of the home library
	*/
	private static RoundRobinLibraryItf createHomeLibrary(String path) throws Exception {
		File mountDirectory = new File(path);
		if (!mountDirectory.exists()) {
			try {
				mountDirectory.mkdir();
			} catch(Exception e) {
				throw new Exception ("Error to create the home mount library"+path+": "+e.getMessage());
			}
		}
		// Cration de la table de lock
		lockTable = new LockTable(new File(serviceMountLibrary));
		RoundRobinLibrary homeLibrary = new RoundRobinLibrary(path);
		Naming.rebind(serviceURL, (RoundRobinLibraryItf)homeLibrary);
		return (RoundRobinLibraryItf)homeLibrary;
	}
	/**
	* getServiceURL return the URL of RoundRobinService
	*/
	public String getServiceURL() throws RemoteException {
		return serviceURL;
	}
	/**
	* getServicePort return the port of RoundRobinService
	*/
	public int getServicePort() throws RemoteException {
		return servicePort;
	}
	/**
	* getServiceMountDirectory return the library of mount of RoundRobinService
	*/
	public RoundRobinLibraryItf getServiceMountLibrary() throws RemoteException {
		return homeRoundRobinLibrary;
	}
	/**
	* getTimeZone returns the time zone of reference of the rrdService
	*/
	public TimeZone getTimeZone() throws RemoteException {
		return timeZone;
	}
	/**
	* Display usage of the command line
	*/
	private static void PrintUsage () {
		System.out.println("RoundRobinService [filename]");
		System.out.println("file name of config");
		System.exit(1);
	}
	/**
	* Main methode main of the RoundRobinService
	* @param argv: the string array which is the command line
	*/
	public static void main(String argv[]) {
		
		// Gestion de la ligne de commande
		if (argv.length != 1) PrintUsage();
		
		// Enregistre le RoundRobinService auprs du registry
		try {
			initRoundRobinService(argv[0]);
		} catch(Exception e) {
			LogFile.print(e.getMessage());
			e.printStackTrace();
		}
	}
}