package rrdService.util;
import java.io.*;
import java.lang.*;
/**	
* The class ConsolidationFunction specify the consolidation functions 
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="ConsolidationFunction.java">ConsolidationFunction</a>
* @see RoundRobinArchive
*/
public class ConsolidationFunction implements Serializable {
	/**
	* The AVERAGE consolidation function
	*/
	public static final String AVERAGE = "AVERAGE";
	/**
	* The MIN consolidation function
	*/
	public static final String MIN = "MIN";
	/**
	* The MAX consolidation function
	*/
	public static final String MAX = "MAX";
	/**
	* The LAST consolidation function
	*/
	public static final String LAST = "LAST";
	/**
	* Array of consolidation functions
	*/
	private static final String[] CFArray = {AVERAGE, MIN, MAX, LAST};
	/**
	* Consolidation function
	*/
	private String cf;
	/**
	* Constructor of ConsolidationFunction
	* @param cf the string representing the consolidation function
	*/
	public ConsolidationFunction(String cf) throws Exception {
		if(!isValideCF(cf)) throw new Exception ("CF not match");
		this.cf = cf.toUpperCase();
	}
	/**
	* getCFAvailable return the list of consolidation function available
	* @return String[] the list of consolidation function available 
	*/
	public static String[] getCFAvailable() {
		return CFArray;
	}
	/**
	* isValideCF return true if the string parameter is a valide consolidation fonction
	* @param cf the consolidation function to test
	*/
	public static boolean isValideCF(String cf) {
		int i=0;
		while(i<CFArray.length && CFArray[i].equalsIgnoreCase(cf)) i++;
		return !(i==CFArray.length);
	}
	/**
	* Return a String representation of a consolidation function
	*/
	public String toString() {
		return cf;
	}
}