package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class DataContainer allows to stock a list of data source
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="DataContainer.java">DataContainer</a>
* @see Vector
*/
public class DataContainer extends Vector {
	/**
	* Constructs an empty DataContainer so that its internal data array has size 10 and its standard capacity increment is zero. 
	*/
	public DataContainer() {
		super();
	}
    /**
    * Constructs a DataContainer containing the Data of the specified collection, in the order they are returned by the collection's iterator. 
    * @param c the collection whose DataSources are to be placed into this DataContainer.
    */
    public DataContainer(Collection c) {
		super(c);
	}
    /**
    * Constructs an empty DataContainer with the specified initial capacity and with its capacity increment equal to zero. 
    * param initialCapacity the initial capacity of the DataContainer.
    */
    public DataContainer(int initialCapacity) throws IllegalArgumentException {
		super(initialCapacity);
	}
	/**
    * Constructs an empty DataContainer with the specified initial capacity and capacity increment.
    * @param initialCapacity the initial capacity of the DataContainer.
    * @param capacityIncrement the amount by which the capacity is increased when the DataContainer overflows
    */
    public DataContainer(int initialCapacity, int capacityIncrement) throws IllegalArgumentException {
		super(initialCapacity, capacityIncrement);
	}
	/**
    * Returns a clone of this DataContainer.
    * return DataContainer
    */
    public DataContainer cloneDataContainer() {
    	return (DataContainer)clone();
   	}
    /**
    * Returns the component at the specified index. 
    * @param index an index into this DataContainer.
    * @return Data
    */
 	public Data dataAt(int index) throws ArrayIndexOutOfBoundsException {
 		return (Data)elementAt(index);
 	}
    /**
    * Returns the first component (the item at index 0) of this DataContainer. 
    * @return Data
    */ 
    public Data firstData() throws NoSuchElementException {
    	return (Data)firstElement();
    }
    /**
    * Returns the Data at the specified position in this DataContainer.
    * @param index index of Data to return.
    * @return Data
    */
 	public Data getData(int index) throws ArrayIndexOutOfBoundsException {
 		return (Data)get(index);
 	}
    /**
    * Returns the last component of the DataContainer. 
    * @return Data
    */      
 	public Data lastDatae() throws NoSuchElementException {
 		return (Data)lastElement();
 	}
    /**
    * Removes the Data at the specified position in this DataContainer. 
    * @param index index of Data to remove
    * @return Data
    */      
 	public Data removeData(int index) throws ArrayIndexOutOfBoundsException {
 		return (Data)remove(index);
 	}
    /**
    * Replaces the Data at the specified position in this DataContainer with the specified Data. 
    * @param index index of Data to replace.
	* @param data the data to be stored at the specified position.
    * @return Data
    */
    public Data setData(int index, Data data) throws ArrayIndexOutOfBoundsException, IllegalArgumentException {
    	return (Data)set(index, data);
    }
 	/**
    * Returns an array containing all of the Data in this DataContainer in the correct order. 
    * @return Data
    */      
 	public Data[] toDataArray() {
 		return (Data[])toArray();
 	}
 	/**
 	* Returns an array containing all of the Data in this DataContainer in the correct order. 
 	* @param a the array into which the Data of the DataContainer are to be stored, if it is big enough; otherwise, a new array of the same runtime type is allocated for this purpose.
    * @return Data
 	*/
 	public Data[] toDataArray(Data[] a) throws ArrayStoreException {
 		return (Data[])toArray(a);
 	}
}