package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class DataSourceContainer allows to stock a list of data source
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="DataSourceContainer.java">DataSourceContainer</a>
* @see Vector DataSource
*/
public class DataSourceContainer extends Vector {
	/**
	* Constructs an empty DataSourceContainer so that its internal data array has size 10 and its standard capacity increment is zero. 
	*/
	public DataSourceContainer() {
		super();
	}
    /**
    * Constructs a DataSourceContainer containing the DataSource of the specified collection, in the order they are returned by the collection's iterator. 
    * @param c the collection whose DataSources are to be placed into this DataSourceContainer.
    */
    public DataSourceContainer(Collection c) {
		super(c);
	}
    /**
    * Constructs an empty DataSourceContainer with the specified initial capacity and with its capacity increment equal to zero. 
    * param initialCapacity the initial capacity of the DataSourceContainer.
    */
    public DataSourceContainer(int initialCapacity) throws IllegalArgumentException {
		super(initialCapacity);
	}
	/**
    * Constructs an empty DataSourceContainer with the specified initial capacity and capacity increment.
    * @param initialCapacity the initial capacity of the DataSourceContainer.
    * @param capacityIncrement the amount by which the capacity is increased when the DataSourceContainer overflows
    */
    public DataSourceContainer(int initialCapacity, int capacityIncrement) throws IllegalArgumentException {
		super(initialCapacity, capacityIncrement);
	}
	/**
    * Returns a clone of this DataSourceContainer.
    * return DataSourceContainer
    */
    public DataSourceContainer cloneDataSourceContainer() {
    	return (DataSourceContainer)clone();
   	}
    /**
    * Returns the component at the specified index. 
    * @param index an index into this DataSourceContainer.
    * @return DataSource
    */
 	public DataSource dataSourceAt(int index) throws ArrayIndexOutOfBoundsException {
 		return (DataSource)elementAt(index);
 	}
    /**
    * Returns the first component (the item at index 0) of this DataSourceContainer. 
    * @return DataSource
    */ 
    public DataSource firstDataSource() throws NoSuchElementException {
    	return (DataSource)firstElement();
    }
    /**
    * Returns the DataSource at the specified position in this DataSourceContainer.
    * @param index index of DataSource to return.
    * @return DataSource
    */
 	public DataSource getDataSource(int index) throws ArrayIndexOutOfBoundsException {
 		return (DataSource)get(index);
 	}
    /**
    * Returns the last component of the DataSourceContainer. 
    * @return DataSource
    */      
 	public DataSource lastDataSource() throws NoSuchElementException {
 		return (DataSource)lastElement();
 	}
    /**
    * Removes the DataSource at the specified position in this DataSourceContainer. 
    * @param index index of DataSource to remove
    * @return DataSource
    */      
 	public DataSource removeDataSource(int index) throws ArrayIndexOutOfBoundsException {
 		return (DataSource)remove(index);
 	}
    /**
    * Replaces the DataSource at the specified position in this DataSourceContainer with the specified DataSource. 
    * @param index index of DataSource to replace.
	* @param lib RoundRobinDataBase to be stored at the specified position.
    * @return DataSource
    */
    public DataSource setDataSource(int index, DataSource lib) throws ArrayIndexOutOfBoundsException, IllegalArgumentException {
    	return (DataSource)set(index, lib);
    }
 	/**
    * Returns an array containing all of the DataSource in this DataSourceContainer in the correct order. 
    * @return DataSource
    */      
 	public DataSource[] toDataSourceArray() {
 		return (DataSource[])toArray();
 	}
 	/**
 	* Returns an array containing all of the DataSource in this DataSourceContainer in the correct order. 
 	* @param a the array into which the DataSource of the DataSourceContainer are to be stored, if it is big enough; otherwise, a new array of the same runtime type is allocated for this purpose.
    * @return DataSource
 	*/
 	public DataSource[] toDataSourceArray(DataSource[] a) throws ArrayStoreException {
 		return (DataSource[])toArray(a);
 	}
 	/**
 	* toString return a string representation of this DataSourceContainer
 	*/
 	public String toString() {
 		String result = new String();
 		for (int i=0; i<size(); i++) {
 			result += dataSourceAt(i).toStringAll();
 		}
 		return result;
 	}
}