package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class GraphicObjectContainer allows to stock a list of GraphicObject
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="GraphicObjectContainer.java">GraphicObjectContainer</a>
* @see Vector GraphicObject
*/
public class GraphicObjectContainer extends Vector {
	/**
	* Constructs an empty GraphicObjectContainer so that its internal data array has size 10 and its standard capacity increment is zero. 
	*/
	public GraphicObjectContainer() {
		super();
	}
    /**
    * Constructs a GraphicObjectContainer containing the GraphicObject of the specified collection, in the order they are returned by the collection's iterator. 
    * @param c the collection whose DataSources are to be placed into this GraphicObjectContainer.
    */
    public GraphicObjectContainer(Collection c) {
		super(c);
	}
    /**
    * Constructs an empty GraphicObjectContainer with the specified initial capacity and with its capacity increment equal to zero. 
    * param initialCapacity the initial capacity of the GraphicObjectContainer.
    */
    public GraphicObjectContainer(int initialCapacity) throws IllegalArgumentException {
		super(initialCapacity);
	}
	/**
    * Constructs an empty GraphicObjectContainer with the specified initial capacity and capacity increment.
    * @param initialCapacity the initial capacity of the GraphicObjectContainer.
    * @param capacityIncrement the amount by which the capacity is increased when the GraphicObjectContainer overflows
    */
    public GraphicObjectContainer(int initialCapacity, int capacityIncrement) throws IllegalArgumentException {
		super(initialCapacity, capacityIncrement);
	}
	/**
    * Returns a clone of this GraphicObjectContainer.
    * return GraphicObjectContainer
    */
    public GraphicObjectContainer cloneGraphicObjectContainer() {
    	return (GraphicObjectContainer)clone();
   	}
    /**
    * Returns the component at the specified index. 
    * @param index an index into this GraphicObjectContainer.
    * @return GraphicObject
    */
 	public GraphicObject graphicObjectAt(int index) throws ArrayIndexOutOfBoundsException {
 		return (GraphicObject)elementAt(index);
 	}
    /**
    * Returns the first component (the item at index 0) of this GraphicObjectContainer. 
    * @return GraphicObject
    */ 
    public GraphicObject firstGraphicObject() throws NoSuchElementException {
    	return (GraphicObject)firstElement();
    }
    /**
    * Returns the GraphicObject at the specified position in this GraphicObjectContainer.
    * @param index index of GraphicObject to return.
    * @return GraphicObject
    */
 	public GraphicObject getGraphicObject(int index) throws ArrayIndexOutOfBoundsException {
 		return (GraphicObject)get(index);
 	}
    /**
    * Returns the last component of the GraphicObjectContainer. 
    * @return GraphicObject
    */      
 	public GraphicObject lastGraphicObject() throws NoSuchElementException {
 		return (GraphicObject)lastElement();
 	}
    /**
    * Removes the GraphicObject at the specified position in this GraphicObjectContainer. 
    * @param index index of GraphicObject to remove
    * @return GraphicObject
    */      
 	public GraphicObject removeGraphicObject(int index) throws ArrayIndexOutOfBoundsException {
 		return (GraphicObject)remove(index);
 	}
    /**
    * Replaces the GraphicObject at the specified position in this GraphicObjectContainer with the specified GraphicObject. 
    * @param index index of GraphicObject to replace.
	* @param graphicObject the graphicObject to be stored at the specified position.
    * @return GraphicObject
    */
    public GraphicObject setGraphicObject(int index, GraphicObject graphicObject) throws ArrayIndexOutOfBoundsException, IllegalArgumentException {
    	return (GraphicObject)set(index, graphicObject);
    }
 	/**
    * Returns an array containing all of the GraphicObject in this GraphicObjectContainer in the correct order. 
    * @return GraphicObject
    */      
 	public GraphicObject[] toGraphicObjectArray() {
 		return (GraphicObject[])toArray();
 	}
 	/**
 	* Returns an array containing all of the GraphicObject in this GraphicObjectContainer in the correct order. 
 	* @param a the array into which the GraphicObject of the GraphicObjectContainer are to be stored, if it is big enough; otherwise, a new array of the same runtime type is allocated for this purpose.
    * @return GraphicObject
 	*/
 	public GraphicObject[] toDataArray(GraphicObject[] a) throws ArrayStoreException {
 		return (GraphicObject[])toArray(a);
 	}
 	/**
 	* Returns a string representation of a commentContainer
 	*/
 	public String toString() {
 		String result = new String();
 		for (int i=0; i<size(); i++) {
 			result += graphicObjectAt(i).toString()+" ";
 		}
 		return result;
 	}
}