package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class GraphicPrint
* Calculate the chosen consolidation function <EM>
* <FONT SIZE="-1">CF</FONT></EM> over the data-source
* variable <EM>vname</EM> and <CODE>printf</CODE> the result is printed into the graph below the legend.
* In the <EM>format</EM> string there should be a '%lf' or '%le' marker in the
* place where the number should be printed.
* <P>If an additional '%s' is found
* <FONT SIZE="-1">AFTER</FONT> the marker, the value will be scaled
* and an appropriate
* <FONT SIZE="-1">SI</FONT> magnitude unit will be printed in place of the '%s'
* marker. The scaling will take the '--base' argument into consideration!</P>
* <P>If a
* <FONT SIZE="-1">'%S'</FONT> is used instead of a '%s', then instead of calculating the
* appropriate
* <FONT SIZE="-1">SI</FONT> magnitude unit for this value, the previously calculated
* <FONT SIZE="-1">SI</FONT> magnitude unit will be used. This is useful if you want all the values
* in a
* <FONT SIZE="-1">PRINT</FONT> statement to have the same
* <FONT SIZE="-1">SI</FONT> magnitude unit. If there was
* no previous
* <FONT SIZE="-1">SI</FONT> magnitude calculation made, then
* <FONT SIZE="-1">'%S'</FONT> behaves like a '%s',
* unless the value is 0, in which case it does not remember a
* <FONT SIZE="-1">SI</FONT> magnitude
* unit and a
* <FONT SIZE="-1">SI</FONT> magnitude unit will only be calculated when the next '%s' is
* seen or the next
* <FONT SIZE="-1">'%S'</FONT> for a non-zero value.</P>
* <P>If you want to put a '%' into your
* <FONT SIZE="-1">PRINT</FONT> string, use '%%' instead.
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="GraphicPrint.java">GraphicPrint</a>
* @see RoundRobinGraphic 
*/
public class GraphicPrint implements Serializable {
	/**
	* virtualName the virtual name for this GraphicPrint
	*/
	private String virtualName;
	/**
	* consolidationFunction the consolidation function of this GraphicPrint
	*/
	private ConsolidationFunction consolidationFunction;
	/**
	* format the format of text of this GraphicPrint
	*/
	private String format;
	/**
	* Constructor of GraphicPrint
	* @param virtualName the virtual name for this GraphicPrint
	* @param consolidationFunction the consolidation function of this GraphicPrint
	* @param format the format of text of this GraphicPrint
	*/
	public GraphicPrint(String virtualName,
						ConsolidationFunction consolidationFunction,
						String format) {
		setVirtualName(virtualName);
		setConsolidationFunction(consolidationFunction);
		setFormat(format);
	}
	/**
	* Replaces the virtual name for this GraphicPrint
	* @param virtualName the virtual name for this GraphicPrint to set
	*/
	public void setVirtualName(String virtualName) {
		this.virtualName = virtualName;
	}
	/**
	* Replaces the consolidation function of this GraphicPrint
	* @param consolidationFunction the consolidation function of this GraphicPrint to set
	*/
	public void setConsolidationFunction(ConsolidationFunction consolidationFunction) {
		this.consolidationFunction = consolidationFunction;
	}
	/**
	* Replaces the format of text of this GraphicPrint
	* @param format the format of text of this GraphicPrint
	*/
	public void setFormat(String format) {
		this.format = format;
	}
	/**
	* Retruns the virtual name for this GraphicPrint
	*/
	public String getVirtualName() {
		return this.virtualName;
	}
	/**
	* Returns the consolidation function of this GraphicPrint
	*/
	public ConsolidationFunction getConsolidationFunction() {
		return this.consolidationFunction;
	}
	/**
	* Returns the format of text of this GraphicPrint
	*/
	public String getFormat() {
		return this.format;
	}
	/**
	* Returns a string representation of this GraphicPrint
	*/
	public String toString(){
		return "GPRINT:"+virtualName+":"+consolidationFunction.toString()+":"+format;
	}
}