package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
import java.awt.Color;
/**	
* The class HRuleGraphicObject Like GraphicPrint but the text is simply printed into the graph. Draw a horizontal rule into the graph and optionally add a legend 
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="HRuleGraphicObject.java">HRuleGraphicObject</a>
* @see RoundRobinGraphic Comment
*/
public class HRuleGraphicObject extends GraphicObject implements Serializable {
	/**
	* value to print
	*/
	private double value;
	/**
	* Constructor of HRuleGraphicObject
	* @param value the value to print
	* @param color the color of the text on graphic
	*/
	public HRuleGraphicObject(double value,
						Color color) {
		setValue(value);
		setColor(color);
		this.legend = null;
	}
	/**
	* Constructor of HRuleGraphicObject
	* @param value the value to print
	* @param color the color of the text on graphic
	* @param legend the legend of the text on graphic
	*/
	public HRuleGraphicObject(double value,
						Color color,
						String legend) {
		setValue(value);
		setColor(color);
		setLegend(legend);
	}
	/**
	* Replaces the value to print
	* @param value the value to print
	*/
	public void setValue(double value) {
		this.value = value;
	}
	/**
	* Returns the value to print
	*/
	public double getValue() {
		return this.value;
	}
	/**
	* Returns a string representation of this HRuleGraphicObject
	*/
	public String toString(){
		String result = new String();
		RoundRobinColor c = new RoundRobinColor(String.valueOf(value), color);
		if (legend != null)
			result = "HRULE:"+c.toString()+":"+legend;
		else 
			result = "HRULE:"+c.toString();
		return result;
	}
}