package rrdService.util;
import rrdService.service.*;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class MEVirtualDataSourceContainer allows to transmits a Container of MEVirtualDataSourceContainer to client
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="MEVirtualDataSourceContainer.java">MEVirtualDataSourceContainer</a>
* @see Vector MathExpressionVirtualDataSource
*/
public class MEVirtualDataSourceContainer extends Vector {
	/**
	* Constructs an empty MEVirtualDataSourceContainer so that its internal data array has size 10 and its standard capacity increment is zero. 
	*/
	public MEVirtualDataSourceContainer() {
		super();
	}
    /**
    * Constructs a MEVirtualDataSourceContainer containing the MathExpressionVirtualDataSource of the specified collection, in the order they are returned by the collection's iterator. 
    * @param c the collection whose VirtualDataSources are to be placed into this MEVirtualDataSourceContainer.
    */
    public MEVirtualDataSourceContainer(Collection c) {
		super(c);
	}
    /**
    * Constructs an empty MEVirtualDataSourceContainer with the specified initial capacity and with its capacity increment equal to zero. 
    * param initialCapacity the initial capacity of the MEVirtualDataSourceContainer.
    */
    public MEVirtualDataSourceContainer(int initialCapacity) throws IllegalArgumentException {
		super(initialCapacity);
	}
	/**
    * Constructs an empty MEVirtualDataSourceContainer with the specified initial capacity and capacity increment.
    * @param initialCapacity the initial capacity of the MEVirtualDataSourceContainer.
    * @param capacityIncrement the amount by which the capacity is increased when the MEVirtualDataSourceContainer overflows
    */
    public MEVirtualDataSourceContainer(int initialCapacity, int capacityIncrement) throws IllegalArgumentException {
		super(initialCapacity, capacityIncrement);
	}
	/**
    * Returns a clone of this MEVirtualDataSourceContainer.
    * return MEVirtualDataSourceContainer
    */
    public MEVirtualDataSourceContainer cloneMEVirtualDataSourceContainer() {
    	return (MEVirtualDataSourceContainer)clone();
   	}
    /**
    * Returns the component at the specified index. 
    * @param index an index into this MEVirtualDataSourceContainer.
    * @return MathExpressionVirtualDataSource
    */
 	public MathExpressionVirtualDataSource mEVirtualDataSourceAt(int index) throws ArrayIndexOutOfBoundsException {
 		return (MathExpressionVirtualDataSource)elementAt(index);
 	}
    /**
    * Returns the first component (the item at index 0) of this MEVirtualDataSourceContainer. 
    * @return MathExpressionVirtualDataSource
    */ 
    public MathExpressionVirtualDataSource firstMEVirtualDataSource() throws NoSuchElementException {
    	return (MathExpressionVirtualDataSource)firstElement();
    }
    /**
    * Returns the MathExpressionVirtualDataSource at the specified position in this MEVirtualDataSourceContainer.
    * @param index index of MathExpressionVirtualDataSource to return.
    * @return MathExpressionVirtualDataSource
    */
 	public MathExpressionVirtualDataSource getMEVirtualDataSource(int index) throws ArrayIndexOutOfBoundsException {
 		return (MathExpressionVirtualDataSource)get(index);
 	}
    /**
    * Returns the last component of the MEVirtualDataSourceContainer. 
    * @return MathExpressionVirtualDataSource
    */      
 	public MathExpressionVirtualDataSource lastMEVirtualDataSource() throws NoSuchElementException {
 		return (MathExpressionVirtualDataSource)lastElement();
 	}
    /**
    * Removes the MathExpressionVirtualDataSource at the specified position in this MEVirtualDataSourceContainer. 
    * @param index index of MathExpressionVirtualDataSource to remove
    * @return MathExpressionVirtualDataSource
    */      
 	public MathExpressionVirtualDataSource removeMEVirtualDataSource(int index) throws ArrayIndexOutOfBoundsException {
 		return (MathExpressionVirtualDataSource)remove(index);
 	}
    /**
    * Replaces the MathExpressionVirtualDataSource at the specified position in this MEVirtualDataSourceContainer with the specified MathExpressionVirtualDataSource. 
    * @param index index of MathExpressionVirtualDataSource to replace.
	* @param lib RoundRobinDataBase to be stored at the specified position.
    * @return MathExpressionVirtualDataSource
    */
    public MathExpressionVirtualDataSource setMEVirtualDataSource(int index, MathExpressionVirtualDataSource mEVirtualDataSource) throws ArrayIndexOutOfBoundsException, IllegalArgumentException {
    	return (MathExpressionVirtualDataSource)set(index, mEVirtualDataSource);
    }
 	/**
    * Returns an array containing all of the MathExpressionVirtualDataSource in this MEVirtualDataSourceContainer in the correct order. 
    * @return MathExpressionVirtualDataSource
    */      
 	public MathExpressionVirtualDataSource[] toMEVirtualDataSourceArray() {
 		return (MathExpressionVirtualDataSource[])toArray();
 	}
 	/**
 	* Returns an array containing all of the MathExpressionVirtualDataSource in this MEVirtualDataSourceContainer in the correct order. 
 	* @param a the array into which the MathExpressionVirtualDataSource of the MEVirtualDataSourceContainer are to be stored, if it is big enough; otherwise, a new array of the same runtime type is allocated for this purpose.
    * @return MathExpressionVirtualDataSource
 	*/
 	public MathExpressionVirtualDataSource[] toMEVirtualDataSourceArray(MathExpressionVirtualDataSource[] a) throws ArrayStoreException {
 		return (MathExpressionVirtualDataSource[])toArray(a);
 	}
 	/**
 	* Returns a string representation of this MEVirtualDataSourceContainer
 	*/
 	public String toString() {
 		String result = new String();
 		for (int i=0; i<size(); i++) {
 			result += mEVirtualDataSourceAt(i).toString()+" ";
 		}
 		return result;
 	}
}