package rrdService.util;
import rrdService.service.*;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class RoundRobinContainer allows to transmits a Container of RoundRobinDataBase to client
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="RoundRobinContainer.java">RoundRobinContainer</a>
* @see Vector RoundRobin
*/
public class RoundRobinContainer extends Vector {
	/**
	* Constructs an empty RoundRobinContainer so that its internal data array has size 10 and its standard capacity increment is zero. 
	*/
	public RoundRobinContainer() {
		super();
	}
    /**
    * Constructs a RoundRobinContainer containing the RoundRobinItf of the specified collection, in the order they are returned by the collection's iterator. 
    * @param c the collection whose RoundRobinItfs are to be placed into this RoundRobinContainer.
    */
    public RoundRobinContainer(Collection c) {
		super(c);
	}
    /**
    * Constructs an empty RoundRobinContainer with the specified initial capacity and with its capacity increment equal to zero. 
    * param initialCapacity the initial capacity of the RoundRobinContainer.
    */
    public RoundRobinContainer(int initialCapacity) throws IllegalArgumentException {
		super(initialCapacity);
	}
	/**
    * Constructs an empty RoundRobinContainer with the specified initial capacity and capacity increment.
    * @param initialCapacity the initial capacity of the RoundRobinContainer.
    * @param capacityIncrement the amount by which the capacity is increased when the RoundRobinContainer overflows
    */
    public RoundRobinContainer(int initialCapacity, int capacityIncrement) throws IllegalArgumentException {
		super(initialCapacity, capacityIncrement);
	}
	/**
    * Returns a clone of this RoundRobinContainer.
    * return RoundRobinContainer
    */
    public RoundRobinContainer cloneRoundRobinContainer() {
    	return (RoundRobinContainer)clone();
   	}
    /**
    * Returns the component at the specified index. 
    * @param index an index into this RoundRobinContainer.
    * @return RoundRobinItf
    */
 	public RoundRobinItf roundRobinAt(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinItf)elementAt(index);
 	}
    /**
    * Returns the first component (the item at index 0) of this RoundRobinContainer. 
    * @return RoundRobinItf
    */ 
    public RoundRobinItf firstRoundRobin() throws NoSuchElementException {
    	return (RoundRobinItf)firstElement();
    }
    /**
    * Returns the RoundRobinItf at the specified position in this RoundRobinContainer.
    * @param index index of RoundRobinItf to return.
    * @return RoundRobinItf
    */
 	public RoundRobinItf getRoundRobin(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinItf)get(index);
 	}
    /**
    * Returns the last component of the RoundRobinContainer. 
    * @return RoundRobinItf
    */      
 	public RoundRobinItf lastRoundRobin() throws NoSuchElementException {
 		return (RoundRobinItf)lastElement();
 	}
    /**
    * Removes the RoundRobinItf at the specified position in this RoundRobinContainer. 
    * @param index index of RoundRobinItf to remove
    * @return RoundRobinItf
    */      
 	public RoundRobinItf removeRoundRobin(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinItf)remove(index);
 	}
    /**
    * Replaces the RoundRobinItf at the specified position in this RoundRobinContainer with the specified RoundRobinItf. 
    * @param index index of RoundRobinItf to replace.
	* @param lib RoundRobinDataBase to be stored at the specified position.
    * @return RoundRobinItf
    */
    public RoundRobinItf setRoundRobin(int index, RoundRobinItf lib) throws ArrayIndexOutOfBoundsException, IllegalArgumentException {
    	return (RoundRobinItf)set(index, lib);
    }
 	/**
    * Returns an array containing all of the RoundRobinItf in this RoundRobinContainer in the correct order. 
    * @return RoundRobinItf
    */      
 	public RoundRobinItf[] toRoundRobinArray() {
 		return (RoundRobinItf[])toArray();
 	}
 	/**
 	* Returns an array containing all of the RoundRobinItf in this RoundRobinContainer in the correct order. 
 	* @param a the array into which the RoundRobinItf of the RoundRobinContainer are to be stored, if it is big enough; otherwise, a new array of the same runtime type is allocated for this purpose.
    * @return RoundRobinItf
 	*/
 	public RoundRobinItf[] toRoundRobinArray(RoundRobinItf[] a) throws ArrayStoreException {
 		return (RoundRobinItf[])toArray(a);
 	}
}