package rrdService.util;
import rrdService.service.*;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class RoundRobinLibraryContainer allows to transmits a Container of RoundRobinLibrary to client
* @author Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="RoundRobinLibraryContainer.java">RoundRobinLibraryContainer</a>
* @see Vector RoundRobinLibrary
*/
public class RoundRobinLibraryContainer extends Vector {
	/**
	* Constructs an empty RoundRobinLibraryContainer so that its internal data array has size 10 and its standard capacity increment is zero. 
	*/
	public RoundRobinLibraryContainer() {
		super();
	}
    /**
    * Constructs a RoundRobinLibraryContainer containing the RoundRobinLibraryItf of the specified collection, in the order they are returned by the collection's iterator. 
    * @param c the collection whose RoundRobinLibraryItfs are to be placed into this RoundRobinLibraryContainer.
    */
    public RoundRobinLibraryContainer(Collection c) {
		super(c);
	}
    /**
    * Constructs an empty RoundRobinLibraryContainer with the specified initial capacity and with its capacity increment equal to zero. 
    * param initialCapacity the initial capacity of the RoundRobinLibraryContainer.
    */
    public RoundRobinLibraryContainer(int initialCapacity) throws IllegalArgumentException {
		super(initialCapacity);
	}
	/**
    * Constructs an empty RoundRobinLibraryContainer with the specified initial capacity and capacity increment.
    * @param initialCapacity the initial capacity of the RoundRobinLibraryContainer.
    * @param capacityIncrement the amount by which the capacity is increased when the RoundRobinLibraryContainer overflows
    */
    public RoundRobinLibraryContainer(int initialCapacity, int capacityIncrement) throws IllegalArgumentException {
		super(initialCapacity, capacityIncrement);
	}
	/**
    * Returns a clone of this RoundRobinLibraryContainer.
    * return RoundRobinLibraryContainer
    */
    public RoundRobinLibraryContainer cloneRoundRobinLibraryContainer() {
    	return (RoundRobinLibraryContainer)clone();
   	}
    /**
    * Returns the component at the specified index. 
    * @param index an index into this RoundRobinLibraryContainer.
    * @return RoundRobinLibraryItf
    */
 	public RoundRobinLibraryItf roundRobinLibraryAt(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinLibraryItf)elementAt(index);
 	}
    /**
    * Returns the first component (the item at index 0) of this RoundRobinLibraryContainer. 
    * @return RoundRobinLibraryItf
    */ 
    public RoundRobinLibraryItf firstRoundRobinLibrary() throws NoSuchElementException {
    	return (RoundRobinLibraryItf)firstElement();
    }
    /**
    * Returns the RoundRobinLibraryItf at the specified position in this RoundRobinLibraryContainer.
    * @param index index of RoundRobinLibraryItf to return.
    * @return RoundRobinLibraryItf
    */
 	public RoundRobinLibraryItf getRoundRobinLibrary(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinLibraryItf)get(index);
 	}
    /**
    * Returns the last component of the RoundRobinLibraryContainer. 
    * @return RoundRobinLibraryItf
    */      
 	public RoundRobinLibraryItf lastRoundRobinLibrary() throws NoSuchElementException {
 		return (RoundRobinLibraryItf)lastElement();
 	}
    /**
    * Removes the RoundRobinLibraryItf at the specified position in this RoundRobinLibraryContainer. 
    * @param index index of RoundRobinLibraryItf to remove
    * @return RoundRobinLibraryItf
    */      
 	public RoundRobinLibraryItf removeRoundRobinLibrary(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinLibraryItf)remove(index);
 	}
    /**
    * Replaces the RoundRobinLibraryItf at the specified position in this RoundRobinLibraryContainer with the specified RoundRobinLibraryItf. 
    * @param index index of RoundRobinLibraryItf to replace.
	* @param lib RoundRobinLibrary to be stored at the specified position.
    * @return RoundRobinLibraryItf
    */
    public RoundRobinLibraryItf setRoundRobinLibrary(int index, RoundRobinLibraryItf lib) throws ArrayIndexOutOfBoundsException, IllegalArgumentException {
    	return (RoundRobinLibraryItf)set(index, lib);
    }
 	/**
    * Returns an array containing all of the RoundRobinLibraryItf in this RoundRobinLibraryContainer in the correct order. 
    * @return RoundRobinLibraryItf
    */      
 	public RoundRobinLibraryItf[] toRoundRobinLibraryArray() {
 		return (RoundRobinLibraryItf[])toArray();
 	}
 	/**
 	* Returns an array containing all of the RoundRobinLibraryItf in this RoundRobinLibraryContainer in the correct order. 
 	* @param a the array into which the RoundRobinLibraryItf of the RoundRobinLibraryContainer are to be stored, if it is big enough; otherwise, a new array of the same runtime type is allocated for this purpose.
    * @return RoundRobinLibraryItf
 	*/
 	public RoundRobinLibraryItf[] toRoundRobinLibraryArray(RoundRobinLibraryItf[] a) throws ArrayStoreException {
 		return (RoundRobinLibraryItf[])toArray(a);
 	}
}