package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
import java.awt.Color;
/**	
* The class StackGraphicObject
* Does the same as <STRONG>
* <FONT SIZE="-1">LINE?</FONT></STRONG>, but the graph gets stacked on top of the previous
* <STRONG>
* <FONT SIZE="-1">LINE?</FONT></STRONG>, <STRONG>
* <FONT SIZE="-1">AREA</FONT></STRONG> or <STRONG>
* <FONT SIZE="-1">STACK</FONT></STRONG> graph. Depending on the type of the
* previous graph, the <STRONG>
* <FONT SIZE="-1">STACK</FONT></STRONG> will be either a <STRONG>
* <FONT SIZE="-1">LINE?</FONT></STRONG> or an <STRONG>
* <FONT SIZE="-1">AREA</FONT></STRONG>.
* This obviously implies that the first <STRONG>
* <FONT SIZE="-1">STACK</FONT></STRONG> must be preceded by an
* <STRONG>
* <FONT SIZE="-1">AREA</FONT></STRONG> or <STRONG>
* <FONT SIZE="-1">LINE?</FONT></STRONG> -- you need something to stack something onto in
* the first place ;)
* <P>Note, that when you
* <FONT SIZE="-1">STACK</FONT> onto
* <FONT SIZE="-1">*UNKNOWN*</FONT> data, rrdtool will not draw
* any graphics ...
* <FONT SIZE="-1">*UNKNOWN*</FONT> is not zero ... if you want it to zero
* then you might want to use a
* <FONT SIZE="-1">CDEF</FONT> argument with
* <FONT SIZE="-1">IF</FONT> and
* <FONT SIZE="-1">UN</FONT> functions to
* turn
* <FONT SIZE="-1">*UNKNOWN*</FONT> into zero ...
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="StackGraphicObject.java">StackGraphicObject</a>
* @see RoundRobinGraphic Comment
*/
public class StackGraphicObject extends AeraGraphicObject {
	/**
	* Constructor of StackGraphicObject
	* @param virtualName the virtual name to print on graphic
	*/
	public StackGraphicObject(String virtualName) {
		super(virtualName);
	}
	/**
	* Constructor of StackGraphicObject
	* @param virtualName the virtual name to print on graphic
	* @param color the color of the text on graphic
	*/
	public StackGraphicObject(String virtualName, Color color) {
		super(virtualName, color);
	}
	/**
	* Constructor of StackGraphicObject
	* @param virtualName the virtual name to print on graphic
	* @param color the color of the text on graphic
	* @param legend the legend of the text on graphic
	*/
	public StackGraphicObject(String virtualName,
						Color color,
						String legend) {
		super(virtualName, color, legend);
	}
	/**
	* Returns a string representation of this stack graphic object
	*/
	public String toString(){
		String result = new String();
		result = "STACK";
		if (color != null) {
			RoundRobinColor c = new RoundRobinColor(virtualName, color);
			result += ":"+c.toString();
		}
		else {
			result += ":"+virtualName;
		}
		if (legend != null) 
			result += ":"+legend;
		return result;
	}
}