package rrdService.util;
import rrdService.service.*;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class Template allows to stock a list of dsname
* @author Pellier Damien 
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="Template.java">Template</a>
* @see Vector
*/
public class Template extends Vector {
	/**
	* Constructs an empty Template so that its internal data array has size 10 and its standard capacity increment is zero. 
	*/
	public Template() {
		super();
	}
    /**
    * Constructs a Template containing the ds-name of the specified collection, in the order they are returned by the collection's iterator. 
    * @param c the collection whose RoundRobinDataBaseItfs are to be placed into this Template.
    */
    public Template(Collection c) {
		super(c);
	}
    /**
    * Constructs an empty Template with the specified initial capacity and with its capacity increment equal to zero. 
    * param initialCapacity the initial capacity of the Template.
    */
    public Template(int initialCapacity) throws IllegalArgumentException {
		super(initialCapacity);
	}
	/**
    * Constructs an empty Template with the specified initial capacity and capacity increment.
    * @param initialCapacity the initial capacity of the Template.
    * @param capacityIncrement the amount by which the capacity is increased when the Template overflows
    */
    public Template(int initialCapacity, int capacityIncrement) throws IllegalArgumentException {
		super(initialCapacity, capacityIncrement);
	}
	/**
    * Returns a clone of this Template.
    * return Template
    */
    public Template cloneTemplate() {
    	return (Template)clone();
   	}
    /**
    * Returns the component at the specified index. 
    * @param index an index into this Template.
    * @return ds-name
    */
 	public String dsNameAt(int index) throws ArrayIndexOutOfBoundsException {
 		return (String)elementAt(index);
 	}
    /**
    * Returns the first component (the item at index 0) of this Template. 
    * @return ds-name
    */ 
    public String firstDsName() throws NoSuchElementException {
    	return (String)firstElement();
    }
    /**
    * Returns the ds-name at the specified position in this Template.
    * @param index index of ds-name to return.
    * @return ds-name
    */
 	public String getDsName(int index) throws ArrayIndexOutOfBoundsException {
 		return (String)get(index);
 	}
    /**
    * Returns the last component of the Template. 
    * @return ds-name
    */      
 	public String lastDsName() throws NoSuchElementException {
 		return (String)lastElement();
 	}
    /**
    * Removes the ds-name at the specified position in this Template. 
    * @param index index of ds-name to remove
    * @return ds-name
    */      
 	public String removeDsName(int index) throws ArrayIndexOutOfBoundsException {
 		return (String)remove(index);
 	}
    /**
    * Replaces the ds-name at the specified position in this Template with the specified ds-name. 
    * @param index index of ds-name to replace.
	* @param dsName RoundRobinDataBase to be stored at the specified position.
    * @return ds-name
    */
    public String setDsName(int index, String dsName) throws ArrayIndexOutOfBoundsException, IllegalArgumentException {
    	return (String)set(index, dsName);
    }
 	/**
    * Returns an array containing all of the ds-name in this Template in the correct order. 
    * @return ds-name
    */      
 	public String[] toTempaleArray() {
 		return (String[])toArray();
 	}
 	/**
 	* Returns an array containing all of the ds-name in this Template in the correct order. 
 	* @param a the array into which the ds-name of the Template are to be stored, if it is big enough; otherwise, a new array of the same runtime type is allocated for this purpose.
    * @return ds-name
 	*/
 	public String[] toTemplateArray(String[] a) throws ArrayStoreException {
 		return (String[])toArray(a);
 	}
 	/**
 	* toString return a string representation of this template
 	*/
 	public String toString() {
 		String result = new String();
 		for (int i=0; i<size(); i++) {
 			result += dsNameAt(i)+":";
 		}
 		return result;
 	}
}