package rrdService.util;
import rrdService.service.*;
import rrdService.client.*;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class Time allows to manage rrdTool time format
* @author Pellier Damien
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="Time.java">Time</a>
* @see Calendar
*/
public class Time implements Serializable {
	/**
	* Calendar representing the time
	*/
	private Calendar calendar = null;
	/**
	* Last Time
	*/
	private long lastTime;
	/**
	* Constructs a Time with the time ritgth now for client
	*/
	public Time() {
		TimeZone timeZone;
		timeZone = RoundRobinServiceClient.getTimeZone();
		this.calendar = Calendar.getInstance(timeZone);	
		this.lastTime = getTime();
	}
	/**
	* Constructs a Time with the specific time for client
	* @param time a long representing the time since 1st January 1970
	*/
	public Time(long time) {
		TimeZone timeZone;
		timeZone = RoundRobinServiceClient.getTimeZone();
		this.calendar = Calendar.getInstance(timeZone);	
		Date date = new Date(time*1000);
		this.calendar.setTime(date);
		this.lastTime = getTime();
	}
	/**
	* Constructs a Time with the time ritgth now for service
	* @param timeZone the time zone of reference
	*/
	public Time(TimeZone timeZone) {
		this.calendar = Calendar.getInstance(timeZone);	
		this.lastTime = getTime();
	}
	/**
	* Constructs a Time with the specific time for service
	* @param time a long representing the time since 1st January 1970
	* @param timeZone the time zone of reference
	*/
	public Time(long time, TimeZone timeZone) {
		this.calendar = Calendar.getInstance(timeZone);	
		Date date = new Date(time*1000);
		this.calendar.setTime(date);
		this.lastTime = getTime();
	}
	/**
	* synchronize resynchronized the time
	* @param sec the number of second to resychronize
	*/
	public Time synchronize(long sec) {
		long oldTime = calendar.getTime().getTime();
		long synchronizeTime = oldTime+sec*1000;
		calendar.setTime(new Date(synchronizeTime));
		return this;
	}
	/**
	* Refresh done Time point to the current time
	*/
	public Time refresh() {
		TimeZone timeZone;
		timeZone = RoundRobinServiceClient.getTimeZone();
		this.calendar = Calendar.getInstance(timeZone);	
		this.lastTime = getTime();
		return this;
	}
	/**
	* getTime returns the UTC time in second since 1st January 1970
	*/
	public long getTime() {
		return this.calendar.getTime().getTime()/1000;
	}
	/**
	* Returns the UTC time in ms since 1st January 1970 
	*/
	public long getMillisecond() {
		return this.calendar.getTime().getTime();
	}
	/**
	* lastTime returns the UTC time in second since the creation or the refresh of this time
	*/
	public Time getLastTime() {
		return new Time(this.lastTime);
	}
	/**
	* getNowTime returns the UTC time rigth now in second 
	*/
	public Time getNowTime() {
		return this;
	}
	/**
	* toString returns a string representation of time
	*/
	public String toString() {
		return String.valueOf(getTime());
	}
}