package rrdService.util;
import rrdService.service.*;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class VirtualDataSource Define virtual name for a data source. This name can then be used in the functions explained below. The DEF call automatically chooses an RRA which contains CF consolidated data in a resolution appropriate for the size of the graph to be drawn. Ideally this means that one data point from the RRA should be represented by one pixel in the graph. If the resolution of the RRA is higher than the resolution of the graph, the data in the RRA will be further consolidated according to the consolidation function ( CF) chosen. 
* @author	Damien Pellier
* @version	1.0
* date : 28/10/2000
* <dt><b>Invariant</b><code>
* </code>
* <dt><b>key-word</b><code>
* <dd>  
* </code>
* @see <a href="VirtualDataSource.java">VirtualDataSource</a>
* @see RoundRobinGraphic 
*/
public class VirtualDataSource implements Serializable {
	/**
	* virtualName virtual name for a data source
	*/
	private String virtualName;
	/**
	* roundRobinDataBase name associate with this virtual data source
	*/
	private String rrdName;
	/**
	* dataSourceName of this virtual data source
	*/
	private String dataSourceName;
	/**
	* consolidationFunction of this virtual data source
	*/
	private ConsolidationFunction consolidationFunction;
	/**
	* Constructor of VirtualDataSource
	* @param virtualName the virtual name for a data source
	* @param rrdName roundRobinDataBase name associate with this virtual data source
	* @param dataSourceName the dataSourceName of this virtual data source
	* @param consolidationFunction the consolidationFunction of this virtual data source
	*/
	public VirtualDataSource(String virtualName,
								String rrdName,
								String dataSourceName,
								ConsolidationFunction consolidationFunction) {
		setVirtualName(virtualName);
		setRrdName(rrdName);
		setDataSourceName(dataSourceName);
		setConsolidationFunction(consolidationFunction);
	}
	/**
	* Replaces the the virtual name for a data source
	* @param virtualName the virtual name for a data source to set
	*/
	public void setVirtualName(String virtualName) {
		this.virtualName = virtualName;
	}
	/**
	* Replaces the roundRobinDataBase name associate with this virtual data source
	* @param rrdName the roundRobinDataBase name associate with this virtual data source to set
	*/
	public void setRrdName(String rrdName) {
		this.rrdName = rrdName;
	}
	/**
	* Replaces the dataSourceName of this virtual data source
	* @param dataSourceName the dataSourceName of this virtual data source to set
	*/
	public void setDataSourceName(String dataSourceName) {
		this.dataSourceName = dataSourceName;
	}
	/**
	* Replaces the consolidationFunction of this virtual data source
	* @param consolidationFunction the consolidationFunction of this virtual data source
	*/
	public void setConsolidationFunction(ConsolidationFunction consolidationFunction) {
		this.consolidationFunction = consolidationFunction;
	}
	/**
	* Returns the the virtual name for a data source
	*/
	public String getVirtualName() {
		return this.virtualName;
	}
	/**
	* Returns the roundRobinDataBase name associate with this virtual data source
	*/
	public String getRrdName() {
		return this.rrdName;
	}
	/**
	* Returns the dataSourceName of this virtual data source
	*/
	public String setDataSourceName() {
		return this.dataSourceName;
	}
	/**
	* Returns the consolidationFunction of this virtual data source
	*/
	public ConsolidationFunction setConsolidationFunction() {
		return this.consolidationFunction;
	}
	/**
	* Returns a string representation of this virtual data source
	*/
	public String toString(){
		String result = new String();
		try {
			result = "DEF:"+virtualName+"="+rrdName+":"+dataSourceName+":"+consolidationFunction.toString();
		} catch(Exception e) {}
		return result;
	}
}