package rrdService.util;
import rrdService.service.*;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class VirtualDataSourceContainer allows to transmits a Container of VirtualDataSourceContainer to client
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="VirtualDataSourceContainer.java">VirtualDataSourceContainer</a>
* @see Vector VirtualDataSource
*/
public class VirtualDataSourceContainer extends Vector {
	/**
	* Constructs an empty VirtualDataSourceContainer so that its internal data array has size 10 and its standard capacity increment is zero. 
	*/
	public VirtualDataSourceContainer() {
		super();
	}
    /**
    * Constructs a VirtualDataSourceContainer containing the VirtualDataSource of the specified collection, in the order they are returned by the collection's iterator. 
    * @param c the collection whose VirtualDataSources are to be placed into this VirtualDataSourceContainer.
    */
    public VirtualDataSourceContainer(Collection c) {
		super(c);
	}
    /**
    * Constructs an empty VirtualDataSourceContainer with the specified initial capacity and with its capacity increment equal to zero. 
    * param initialCapacity the initial capacity of the VirtualDataSourceContainer.
    */
    public VirtualDataSourceContainer(int initialCapacity) throws IllegalArgumentException {
		super(initialCapacity);
	}
	/**
    * Constructs an empty VirtualDataSourceContainer with the specified initial capacity and capacity increment.
    * @param initialCapacity the initial capacity of the VirtualDataSourceContainer.
    * @param capacityIncrement the amount by which the capacity is increased when the VirtualDataSourceContainer overflows
    */
    public VirtualDataSourceContainer(int initialCapacity, int capacityIncrement) throws IllegalArgumentException {
		super(initialCapacity, capacityIncrement);
	}
	/**
    * Returns a clone of this VirtualDataSourceContainer.
    * return VirtualDataSourceContainer
    */
    public VirtualDataSourceContainer cloneVirtualDataSourceContainer() {
    	return (VirtualDataSourceContainer)clone();
   	}
    /**
    * Returns the component at the specified index. 
    * @param index an index into this VirtualDataSourceContainer.
    * @return VirtualDataSource
    */
 	public VirtualDataSource virtualDataSourceAt(int index) throws ArrayIndexOutOfBoundsException {
 		return (VirtualDataSource)elementAt(index);
 	}
    /**
    * Returns the first component (the item at index 0) of this VirtualDataSourceContainer. 
    * @return VirtualDataSource
    */ 
    public VirtualDataSource firstVirtualDataSource() throws NoSuchElementException {
    	return (VirtualDataSource)firstElement();
    }
    /**
    * Returns the VirtualDataSource at the specified position in this VirtualDataSourceContainer.
    * @param index index of VirtualDataSource to return.
    * @return VirtualDataSource
    */
 	public VirtualDataSource getVirtualDataSource(int index) throws ArrayIndexOutOfBoundsException {
 		return (VirtualDataSource)get(index);
 	}
    /**
    * Returns the last component of the VirtualDataSourceContainer. 
    * @return VirtualDataSource
    */      
 	public VirtualDataSource lastVirtualDataSource() throws NoSuchElementException {
 		return (VirtualDataSource)lastElement();
 	}
    /**
    * Removes the VirtualDataSource at the specified position in this VirtualDataSourceContainer. 
    * @param index index of VirtualDataSource to remove
    * @return VirtualDataSource
    */      
 	public VirtualDataSource removeVirtualDataSource(int index) throws ArrayIndexOutOfBoundsException {
 		return (VirtualDataSource)remove(index);
 	}
    /**
    * Replaces the VirtualDataSource at the specified position in this VirtualDataSourceContainer with the specified VirtualDataSource. 
    * @param index index of VirtualDataSource to replace.
	* @param lib RoundRobinDataBase to be stored at the specified position.
    * @return VirtualDataSource
    */
    public VirtualDataSource setVirtualDataSource(int index, VirtualDataSource virtualDataSource) throws ArrayIndexOutOfBoundsException, IllegalArgumentException {
    	return (VirtualDataSource)set(index, virtualDataSource);
    }
 	/**
    * Returns an array containing all of the VirtualDataSource in this VirtualDataSourceContainer in the correct order. 
    * @return VirtualDataSource
    */      
 	public VirtualDataSource[] toVirtualDataSourceArray() {
 		return (VirtualDataSource[])toArray();
 	}
 	/**
 	* Returns an array containing all of the VirtualDataSource in this VirtualDataSourceContainer in the correct order. 
 	* @param a the array into which the VirtualDataSource of the VirtualDataSourceContainer are to be stored, if it is big enough; otherwise, a new array of the same runtime type is allocated for this purpose.
    * @return VirtualDataSource
 	*/
 	public VirtualDataSource[] toVirtualDataSourceArray(VirtualDataSource[] a) throws ArrayStoreException {
 		return (VirtualDataSource[])toArray(a);
 	}
 	/**
 	* Returns a string representation of this VirtualDataSourceContainer
 	*/
 	public String toString() {
 		String result = new String();
 		for (int i=0; i<size(); i++) {
 			result += virtualDataSourceAt(i).toString()+" ";
 		}
 		return result;
 	}
}