package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class XGrid main purpose is to create graphical representations of the data stored in one or several RRDs. Apart from generating graphs, it can also extract numerical reports.
* @author Pellier Damien
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="XGrid.java">XGrid</a>
* @see YGrid RoundRobinGraphic
*/
public class XGrid implements Serializable {
	/**
	* SECOND unit
	*/
	public static final String SECOND = "SECOND";
	/**
	* MINUTE unit
	*/
	public static final String MINUTE = "MINUTE";
	/**
	* HOUR unit
	*/
	public static final String HOUR = "HOUR";
	/**
	* DAY unit
	*/
	public static final String DAY = "DAY";
	/**
	* WEEK unit
	*/
	public static final String WEEK = "WEEK";
	/**
	* MONTH unit
	*/
	public static final String MONTH = "MONTH";
	/**
	* YEAR unit
	*/
	public static final String YEAR = "YEAR";
	/**
	* The base grid unit of the grid
	*/
	private String baseGridUnit;
	/**
	* The base grid interval of the grid
	*/
	private int baseGridInterval;
	/**
	* The major grid unit of the grid
	*/
	private String majorGridUnit;
	/**
	* The major grid interval of the grid
	*/
	private int majorGridInterval;
	/**
	* The label unit of the grid
	*/
	private String labelUnit;
	/**
	* The label interval of the grid
	*/
	private int labelInterval;
	/**
	* The label precision of the grid
	*/
	private int labelPrecision;
	/**
	* The label format of the grid
	*/
	private String labelFormat;
	/**
	* Default grid
	*/
	private boolean defaultGrid = false;
	/**
	* Default constructor of XGrid
	*/
	public XGrid() {
		defaultGrid = true;
	}
	/**
	* Constructor of XGrid
	* @param baseGridUnit The base grid interval of the grid
	* @param baseGridInterval The base grid interval of the grid
	* @param majorGridUnit The major grid unit of the grid
	* @param majorGridInterval The major grid interval of the grid
	* @param labelUnit The label unit of the grid
	* @param labelInterval The label interval of the grid
	* @param labelPrecision The label precision of the grid
	* @param labelFormat The label format of the grid
	*/
	public XGrid(String baseGridUnit,
				int baseGridInterval,
				String majorGridUnit,
				int majorGridInterval,
				String labelUnit,
				int labelInterval,
				int labelPrecision,
				String labelFormat) throws Exception {
		setBaseGridUnit(baseGridUnit);
		setBaseGridInterval(baseGridInterval);
		setMajorGridUnit(majorGridUnit);
		setMajorGridInterval(majorGridInterval);
		setLabelUnit(labelUnit);
		setLabelInterval(labelInterval);
		setLabelPrecision(labelPrecision);
		setLabelFormat(labelFormat);
	}
	/**
	* Replaces the base grid unit of this xgrid
	* @param baseGridUnit The base grid interval of the grid
	*/
	public void setBaseGridUnit(String baseGridUnit) throws Exception {
		if (!isUnit(baseGridUnit)) throw new Exception("The base grid unit not match");
		this.baseGridUnit = baseGridUnit.toUpperCase();
	}
	/**
	* Replaces the base grid interval of this xgrid
	* @param baseGridInterval The base grid interval of the grid
	*/
	public void setBaseGridInterval(int baseGridInterval) {
		this.baseGridInterval = baseGridInterval;
	}
	/**
	* Replaces the major grid unit of this xgrid
	* @param majorGridUnit The major grid unit of the grid
	*/
	public void setMajorGridUnit(String majorGridUnit) throws Exception {
		if (!isUnit(majorGridUnit)) throw new Exception("The major grid unit not match");
		this.majorGridUnit = majorGridUnit.toUpperCase();
	}
	/**
	* Replaces the major grid interval of this xgrid
	* @param majorGridInterval The major grid interval of the grid
	*/
	public void setMajorGridInterval(int majorGridInterval) {
		this.majorGridInterval = majorGridInterval;
	}
	/**
	* Replaces the label unit of this xgrid
	* @param labelUnit The label unit of the grid
	*/
	public void setLabelUnit(String labelUnit) throws Exception {
		if (!isUnit(labelUnit)) throw new Exception("The label unit not match");
		this.labelUnit = labelUnit.toUpperCase();
	}
	/**
	* Replaces the label interval of this xgrid
	* @param labelInterval The label interval of the grid
	*/
	public void setLabelInterval(int labelInterval) {
		this.labelInterval = labelInterval;
	}
	/**
	* Replaces the label precision of this xgrid
	* @param labelInterval The label interval of the grid
	*/
	public void setLabelPrecision(int labelPrecision) {
		this.labelPrecision = labelPrecision;
	}
	/**
	* Replaces the label format of this xgrid
	* @param labelFormat The label format of the grid
	*/
	public void setLabelFormat(String labelFormat) {
		this.labelFormat = labelFormat.toUpperCase();
	}
	/**
	* Returns the base grid unit of this xgrid
	*/
	public String getBaseGridUnit() {
		return this.baseGridUnit;
	}
	/**
	* Returns the base grid interval of this xgrid
	*/
	public int getBaseGridInterval() {
		return this.baseGridInterval;
	}
	/**
	* Returns the major grid unit of this xgrid
	*/
	public String getMajorGridUnit() {
		return this.majorGridUnit;
	}
	/**
	* Returns the major grid interval of this xgrid
	*/
	public int getMajorGridInterval() {
		return this.majorGridInterval;
	}
	/**
	* Returns the label unit of this xgrid
	*/
	public String getLabelUnit() {
		return this.labelUnit;
	}
	/**
	* Returns the label interval of this xgrid
	*/
	public int getLabelInterval() {
		return this.labelInterval;
	}
	/**
	* Returns the label precision of this xgrid
	*/
	public int getLabelPrecision() {
		return this.labelPrecision;
	}
	/**
	* Returns the label format of this xgrid
	*/
	public String getLabelFormat() {
		return this.labelFormat;
	}
	/**
	* Returns true if the string parameter is a valide unit
	* @param unit the string to test
	*/
	public boolean isUnit(String unit) {
		return 	(unit.equalsIgnoreCase(SECOND) ||
				unit.equalsIgnoreCase(MINUTE) ||
				unit.equalsIgnoreCase(HOUR) ||
				unit.equalsIgnoreCase(DAY) ||
				unit.equalsIgnoreCase(WEEK) ||
				unit.equalsIgnoreCase(MONTH) ||
				unit.equalsIgnoreCase(YEAR));
	}			
	/**
	* Returns a string representation of this xgrid
	*/
	public String toString() {
		if (defaultGrid) return "--x-grid none";
		else return "--x-grid "+
					baseGridUnit+":"+String.valueOf(baseGridInterval)+":"+
					majorGridUnit+":"+String.valueOf(majorGridInterval)+":"+
					labelUnit+":"+String.valueOf(labelInterval)+":"+String.valueOf(labelPrecision)+":"+labelFormat;
	}
}